@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from collective.faceted.map.browser.map import MapView
+from imio.smartweb.core.utils import get_scale_url
 from imio.smartweb.core.browser.faceted.views import FolderView
 from Products.Five import BrowserView
 
@@ -15,8 +16,7 @@ class FacetedGeoJSONPopup(BrowserView):
         title = brain.Title
         description = brain.Description
         if brain.has_leadimage:
-            # TODO : beta1 : Get scale url from catalog
-            img_url = f"{url}/@@images/image/mini"
+            img_url = get_scale_url(brain, self.request, "image", "mini")
             return f"""<a href="{url}" title="{title}">
                          <img src="{img_url}" alt="{title}" />
                          <div>
@@ -31,3 +31,7 @@ class FacetedGeoJSONPopup(BrowserView):
                            <span class="popup_description">{description}</span>
                          </div>
                        </a>"""
+
+    def get_scale_url(self, item):
+        request = self.request
+        return get_scale_url(item, request, "image", "preview")
