@@ -80,13 +80,29 @@ class ContactView(SectionView):
         if contact is None:
             return
         contact_url = contact["@id"]
-        # TODO : beta1 : Get scale url from catalog (metadata=image_scales)
-        query = "@search?portal_type=Image&path.depth=1"
+        query = "@search?portal_type=Image&path.depth=1&metadata_fields=image_scales"
         images_url_request = "{}/{}".format(contact_url, query)
         json_images = get_json(images_url_request)
         if json_images is None or len(json_images.get("items", [])) == 0:
             return
-        return batch_results(json_images.get("items"), self.context.nb_results_by_batch)
+        results = []
+        thumb_scale = self.context.image_scale
+        for image in json_images.get("items"):
+            scales = image["image_scales"]["image"][0]["scales"]
+            url = large_url = image["@id"]
+            if thumb_scale in scales:
+                url = f"{url}/{scales[thumb_scale]['download']}"
+            if "extralarge" in scales:
+                large_url = f"{large_url}/{scales['extralarge']['download']}"
+            results.append(
+                {
+                    "title": image["title"],
+                    "description": image["description"],
+                    "image_url": url,
+                    "image_large_url": large_url,
+                }
+            )
+        return batch_results(results, self.context.nb_results_by_batch)
 
     @property
     def days(self):
